Gallery
-------

.. nbgallery::
    :maxdepth: 1
    :reversed:

    examples/compound1.ipynb
    examples/compound2.ipynb
    examples/compound3.ipynb
    examples/cube.ipynb
    examples/cylinder.ipynb
    examples/disc.ipynb
    examples/grids2d.ipynb
    examples/grids3d.ipynb
    examples/import_file.ipynb
    examples/import_gmsh.ipynb
    examples/import_pyvista.ipynb
    examples/joint_cube.ipynb
    examples/lighting.ipynb
    examples/shape_functions_1d.ipynb
    examples/trigridQ4.ipynb
